/**
 * \file PageAdmin.xaml.cs
 * \brief Fonctionnalits administrateur
 * Code regroupant les fonctionnalits administrateur de l'application (gestion des jeux)
 */

using Microsoft.Maui.Controls;
using GameAtlas.Models;
using System.Diagnostics;

namespace GameAtlas.Views;

public partial class PageAdmin : ContentPage
{
    public Manager AdminManager => (App.Current as App).MyManager;
    public PageAdmin()
    {
        InitializeComponent();
    }

    /**
     * \brief Flche de retour en arrire
     * \return void
     */
    async void Back_Tapped(System.Object sender, Microsoft.Maui.Controls.TappedEventArgs e)
    {
        await Navigation.PopAsync();
    }

    /**
     * \brief Bouton d'ajout de jeu
     *        Affiche une succession de pop-up, pour remplir les champs un par un.
     *        Traitement et vrification des champs.
     * \return void
     */
    private async void OnButtonClicked(object sender, EventArgs e)
    {
        string nom = await DisplayPromptAsync("Informations sur le Jeu", "Quel est le Titre ?", placeholder: "GTA VI");
        string sortie = await DisplayPromptAsync("Informations sur le Jeu", "Date de Sortie", placeholder: "JJ/MM/AAAA");
        string plateformes = await DisplayPromptAsync("Informations sur le Jeu", "Plateforme(s), un espace pour sparer", placeholder: "Ex: XOne PC PS5");
        string developpeur = await DisplayPromptAsync("Informations sur le Jeu", "Dveloppeur", placeholder: "Rockstar Games");
        string editeur = await DisplayPromptAsync("Informations sur le Jeu", "Editeur", placeholder: "Take-Two Interactive");
        string note = await DisplayPromptAsync("Informations sur le Jeu", "Note de 0  5", maxLength: 1, placeholder: "5");
        int noteInt = Int32.Parse(note);
        string nbTelechargement = await DisplayPromptAsync("Informations sur le Jeu", "Nombre de Tlchargements (en milliers, ex: 630k)", placeholder: "630");
        int nbTelechargementInt = Int32.Parse(nbTelechargement);
        string genre = await DisplayPromptAsync("Informations sur le Jeu", "Genre(s), un espace pour sparer", placeholder: "Action Aventure");
        string image = await DisplayPromptAsync("Informations sur le Jeu", "Image de couverture (prfrez URL finissant par .png)", placeholder: "http://example.com/monimage.png");

        Jeu adminJeu = new Jeu(nom, sortie, plateformes, developpeur, editeur, noteInt, nbTelechargementInt, genre, image);
        AdminManager.AddJeux(adminJeu);
        AdminManager.SauvegardeDonnees();
        AdminManager.OnPropertyChanged(nameof(AdminManager.ListJeux));

        Debug.WriteLine($"Le jeu \"{adminJeu.Nom}\" a t ajout.");
    }
}